<?php
/*
This file is part of commune. Hack and customize by henri labarre and based on the marvelous sandbox theme

Commune is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

*/

	if ( ! function_exists( 'commune_setup' ) ) :
	function commune_setup() {
	    
	    // Make theme available for translation
	    // Translations can be filed in the /languages/ directory
	    load_theme_textdomain( 'commune', get_template_directory() . '/languages' );
	
	    // add_editor_style support
	    add_editor_style( 'editor-style.css' );
	   
	    //feed
		add_theme_support('automatic-feed-links');
		
		add_theme_support( 'html5', array(
			'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
		) );
	    
		register_nav_menus( array(
			'primary'   => __( 'Top primary menu', 'commune' ),
		) );
	
	    // Post thumbnails support for post
		add_theme_support( 'post-thumbnails', array( 'post' ) ); // Add it for posts
		set_post_thumbnail_size( 220, 165, true ); // Normal post thumbnails
	
	    // This theme allows users to set a custom background
		add_theme_support( 'custom-background' );
	    
	    // This theme allows users to set a custom header image
	    //custom header for 3.4 and compatability for prior version
	
		$args = array(
            'width'               => 980,
            'height'              => 250,
            'default-image'       => '',
            'default-text-color'  => '444',
            'wp-head-callback'    => 'commune_header_style',
            'admin-head-callback' => 'commune_admin_header_style',
	        
		);
	
		$args = apply_filters( 'commune_custom_header', $args );
	
	    add_theme_support( 'custom-header', $args );
	
	
	}
	endif; // commune_setup
	add_action( 'after_setup_theme', 'commune_setup' );

    add_theme_support( 'title-tag' ); 

    if ( ! function_exists( '_wp_render_title_tag' ) ) {
        function theme_slug_render_title() {
    ?>
    <title><?php wp_title( '|', true, 'right' ); ?></title>
    <?php
        }
        add_action( 'wp_head', 'theme_slug_render_title' );
    }

	if ( ! function_exists( 'commune_scripts_styles' ) ) :
	function commune_scripts_styles() {
	
	    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );
	
		// Loads our main stylesheet.
		wp_enqueue_style( 'commune-style', get_stylesheet_uri(), array(), '2014-06-30' );
	
	}
	endif; // commune_scripts_styles
	add_action( 'wp_enqueue_scripts', 'commune_scripts_styles' );
	
	
	if ( ! function_exists( 'commune_header_style' ) ) :
	// gets included in the site header
	function commune_header_style() {
	    if (get_header_image() != ''){
	    ?>
<style type="text/css">
        div#header {
            background: url(<?php header_image(); ?>); height :230px; -moz-border-radius:6px;border-radius:6px;margin:20px 0 0 0;
        }
        <?php if ( 'blank' == get_header_textcolor() ) { ?>
		h1.blogtitle,.description { display: none; }
		<?php } else { ?>
		h1.blogtitle a,.description { color:#<?php header_textcolor() ?>;text-shadow: none; }
    	<?php
		} ?>
</style>
<?php }
	if ( 'blank' == get_header_textcolor() ) { ?>
<style type="text/css">
	h1.blogtitle,.description,.blogtitle { display: none; }
</style>
<?php } else { ?>
<style type="text/css">
	h1.blogtitle a,.blogtitle a,.description,.menu-toggle:before, .search-toggle:before,.site-navigation a { color:#<?php header_textcolor() ?>; }
	.site-navigation a:hover { background:#<?php header_textcolor() ?>; }    
</style>
<?php }
	}
	endif; // commune_header_style
	
	if ( ! function_exists( 'commune_admin_header_style' ) ) :
	// gets included in the admin header
	function commune_admin_header_style() {
	   ?>
<style type="text/css">
        #headimg {
            width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
            height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
        }
</style>
<?php
	}
	endif; // commune_admin_header_style

// Set the content width based on the theme's design and stylesheet.
	if ( ! isset( $content_width ) )
	$content_width = 620;

// Generates semantic classes for BODY and POST element
function commune_category_id_class($classes) {
	global $post;
	if (!is_404() && isset($post))
	foreach((get_the_category($post->ID)) as $category)
		$classes[] = $category->category_nicename;
	return $classes;
}
add_filter('body_class', 'commune_category_id_class');

function commune_tag_id_class($classes) {
	global $post;
	if (!is_404() && isset($post))
	if ( $tags = get_the_tags() )
		foreach ( $tags as $tag )
			$classes[] = 'tag-' . $tag->slug;
	return $classes;
}
add_filter('body_class', 'commune_tag_id_class');

function commune_author_id_class($classes) {
	global $post;
	if (!is_404() && isset($post))
		$classes[] = 'author-' . sanitize_title_with_dashes(strtolower(get_the_author_meta('login')));
	return $classes;
}
add_filter('post_class', 'commune_author_id_class');


// Generates time- and date-based classes for BODY, post DIVs, and comment LIs; relative to GMT (UTC)
function commune_date_classes( $t, &$c, $p = '' ) {
	$t = $t + ( get_option('gmt_offset') * 3600 );
	$c[] = $p . 'y' . gmdate( 'Y', $t ); // Year
	$c[] = $p . 'm' . gmdate( 'm', $t ); // Month
	$c[] = $p . 'd' . gmdate( 'd', $t ); // Day
	$c[] = $p . 'h' . gmdate( 'H', $t ); // Hour
}

// For category lists on category archives: Returns other categories except the current one (redundant)
function commune_cats_meow($glue) {
	$current_cat = single_cat_title( '', false );
	$separator = "\n";
	$cats = explode( $separator, get_the_category_list($separator) );
	foreach ( $cats as $i => $str ) {
		if ( strstr( $str, ">$current_cat<" ) ) {
			unset($cats[$i]);
			break;
		}
	}
	if ( empty($cats) )
		return false;

	return trim(join( $glue, $cats ));
}

// For tag lists on tag archives: Returns other tags except the current one (redundant)
function commune_tag_ur_it($glue) {
	$current_tag = single_tag_title( '', '',  false );
	$separator = "\n";
	$tags = explode( $separator, get_the_tag_list( "", "$separator", "" ) );
	foreach ( $tags as $i => $str ) {
		if ( strstr( $str, ">$current_tag<" ) ) {
			unset($tags[$i]);
			break;
		}
	}
	if ( empty($tags) )
		return false;

	return trim(join( $glue, $tags ));
}

if ( ! function_exists( 'commune_posted_on' ) ) :
// data before post
function commune_posted_on() {
	printf( __( '<span class="%1$s">Posted on</span> %2$s <span class="meta-sep">by</span> %3$s.', 'commune' ),
		'meta-prep meta-prep-author',
		sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="entry-date">%3$s</span></a>',
			get_permalink(),
			esc_attr( get_the_time() ),
			get_the_date()
		),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			sprintf( esc_attr__( 'View all posts by %s', 'commune' ), get_the_author() ),
			get_the_author()
		)
	);
}
endif;

if ( ! function_exists( 'commune_posted_in' ) ) :
// data after post
function commune_posted_in() {
	// Retrieves tag list of current post, separated by commas.
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'This entry was posted in %1$s and tagged %2$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'commune' );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'This entry was posted in %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'commune' );
	} else {
		$posted_in = __( 'Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'commune' );
	}
	// Prints the string, replacing the placeholders.
	printf(
		$posted_in,
		get_the_category_list( ', ' ),
		$tag_list,
		get_permalink(),
		the_title_attribute( 'echo=0' )
	);
}
endif;


// Widgets plugin: intializes the plugin after the widgets above have passed snuff
function commune_widgets_init() {

		register_sidebar(array(
		'name' => 'SidebarTop',
		'description' => 'Top sidebar',
		'id'            => 'sidebartop',
		'before_widget'  =>   "\n\t\t\t" . '<li id="%1$s" class="widget %2$s"><div class="widgetblock">',
		'after_widget'   =>   "\n\t\t\t</div></li>\n",
		'before_title'   =>   "\n\t\t\t\t". '<div class="widgettitleb"><h3 class="widgettitle">',
		'after_title'    =>   "</h3></div>\n" .''
		));
		
		register_sidebar(array(
		'name' => 'SidebarBottom',
		'description' => 'Bottom sidebar',
		'id'            => 'sidebarbottom',
		'before_widget'  =>   "\n\t\t\t" . '<li id="%1$s" class="widget %2$s"><div class="widgetblock">',
		'after_widget'   =>   "\n\t\t\t</div></li>\n",
		'before_title'   =>   "\n\t\t\t\t". '<div class="widgettitleb"><h3 class="widgettitle">',
		'after_title'    =>   "</h3></div>\n" .''
		));

	}

// Runs our code at the end to check that everything needed has loaded
add_action( 'widgets_init', 'commune_widgets_init' );


// Changes default [...] in excerpt to a real link
function commune_excerpt_more($more) {
       global $post;
       $readmore = __(' read more <span class="meta-nav">&raquo;</span>', 'commune' );
	return ' <a href="'. get_permalink($post->ID) . '">' . $readmore . '</a>';
}
add_filter('excerpt_more', 'commune_excerpt_more');


// Adds filters for the description/meta content in archives.php
add_filter( 'archive_meta', 'wptexturize' );
add_filter( 'archive_meta', 'convert_smilies' );
add_filter( 'archive_meta', 'convert_chars' );
add_filter( 'archive_meta', 'wpautop' );

// Remember: the commune is for play.

// footer link 
add_action('wp_footer', 'footer_link');

function footer_link() {	
if ( is_front_page() && !is_paged()) {
	$anchorthemeowner='<a href="http://wp.commune-mairie.fr/" title="commune mairie" target="blank">commune mairie</a>';
  	$textfooter = __('Powered by <a href="http://www.wordpress.org">WordPress</a> and ', 'commune' );
  	$content = '<div id="footerlink"><div class="alignright"><p>' .$textfooter. $anchorthemeowner.'</p></div><div class="clear"></div></div></div>';
  	echo $content;
} else {
	$textfooter = __('Powered by <a href="http://www.wordpress.org">WordPress</a>', 'commune' );
  	$content = '<div id="footerlink"><div class="alignright"><p>' .$textfooter.'</p></div><div class="clear"></div></div></div>';
  	echo $content;
}
}

//Remove <p> in excerpt
function commune_strip_para_tags ($content) {
if ( is_home() && ($paged < 2 )) {
  $content = str_replace( '<p>', '', $content );
  $content = str_replace( '</p>', '', $content );
  return $content;
}
} 

if ( ! function_exists( 'commune_comment' ) ) :
//Comment function
function commune_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
   <li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
      <div class="comment-author vcard">
        <?php echo get_avatar( $comment, 48 ); ?>
		<?php printf(__('<div class="fn">%s</div> ', 'commune'), get_comment_author_link()) ?>
      </div>
        
      <?php if ($comment->comment_approved == '0') : ?>
         <em><?php _e('Your comment is in moderation.', 'commune') ?></em>
         <br />
      <?php endif; ?>

      <div class="comment-meta"><?php printf(__('%1$s - %2$s <span class="meta-sep">|</span> <a href="%3$s" title="Permalink to this comment">Permalink</a>', 'commune'),
										get_comment_date(),
										get_comment_time(),
										'#comment-' . get_comment_ID() );
										edit_comment_link(__('Edit', 'commune'), ' <span class="meta-sep">|</span> <span class="edit-link">', '</span>'); ?></div>
	  <div class="clear"></div>	
			
      <div class="comment-body"><?php comment_text(); ?></div>
      <div class="reply">
         <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
      <?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'commune' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'commune' ), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;
        
//custom menu support
add_action( 'init', 'commune_register_my_menu' );

function commune_register_my_menu() {
	register_nav_menu( 'primary-menu', __( 'Primary Menu', 'commune' ) );
}        


//font for the Title
function commune_google_font() {
?>
<link href='http://fonts.googleapis.com/css?family=Droid+Sans:regular,bold' rel='stylesheet' type='text/css'>	
<?php
}

add_action('wp_head', 'commune_google_font');

?>